==> 2025-11-08-18-15-32-Create-Delight-Remake-Client.Create-Delight-Remake-v0.4.7.3.zip: overrides/kubejs/startup_scripts/creative_tab/kubejs.js <==
StartupEvents.modifyCreativeTab("kubejs:tab", e => {
    e.remove([
        'createdelight:fire_dragonsteel_armorplate',
        'createdelight:ice_dragonsteel_armorplate',
        'createdelight:lightning_dragonsteel_armorplate',
        'createdelight:incomplete_fire_dragonsteel_armorplate',
        'createdelight:incomplete_ice_dragonsteel_armorplate',
        'createdelight:incomplete_lightning_dragonsteel_armorplate',
        'createdelight:fire_dragon_blood_bucket',
        'createdelight:ice_dragon_blood_bucket',
        'createdelight:lightning_dragon_blood_bucket',
        'createdelight:fuel_mixtures_bucket',
        'createdelight:sky_solution_bucket',
        'createdelight:spent_liquor_bucket',
        'createdelight:unrefined_sugar_bucket',
        'createdelight:unfermented_paper_pulp_bucket',
        'createdelight:paper_pulp_bucket',
        'createdelight:radon_bucket',
        'createdelight:cake_batter_bucket',
        'createdelight:egg_yolk_bucket',
        'createdelight:nut_milk_bucket',
        'createdelight:vinegar_bucket',
        'createdelight:malice_solution_bucket',
        'createdelight:artificial_egg_yolk_bucket',
        'createdelight:soya_milk_bucket',
        'createdelight:corn_flour',
        'createdelight:butter',
        'createdelight:oil_dough',
        'createdelight:oil_dough_with_butter',
        'createdelight:puff_pastry',
        'createdelight:board_noodles',
        'createdelight:vermicelli',
        'createdelight:persimmon_cookie_dough',
        'createdelight:lemon_cookie_dough',
        'createdelight:oatmeal_cookie_dough',
        'createdelight:green_tea_cookie_dough',
        'createdelight:cranberry_cookie_dough',
        'createdelight:bayberry_cookie_dough',
        'createdelight:chocolate_cookie_dough',
        'createdelight:honey_cookie_dough',
        'createdelight:sweet_berry_cookie_dough',
        'createdelight:chorus_cookie_dough',
        'createdelight:bat_cookie_dough',
        'createdelight:paw_cookie_dough',
        'createdelight:raw_empanada',
        'createdelight:raw_calamari',
        'createdelight:raw_cheese_pizza',
        'createdelight:oat_bread',
        'createdelight:ketchup_corn_dog',
        'createdelight:mayo_corn_dog',
        'createdelight:salami',
        'createdelight:potato_stew_beef',
        'createdelight:sushi_unrolledroll',
        'createdelight:fugu_roll',
        'createdelight:empty_riceball',
        'createdelight:yorkshire_pudding_and_beef',
        'createdelight:boiling_water_cabbage',
        'createdelight:braised_intestines_in_brown_sauce',
        'createdelight:empty_popsicle',
        'createdelight:potato_stew_beef',
        'createdelight:sushi_unrolledroll',
        'createdelight:forged_steel_sheet',
        'createdelight:andesite_alloy_nugget',
        'createdelight:crushed_raw_desh',
        'createdelight:crushed_raw_ostrum',
        'createdelight:crushed_raw_calorite',
        'createdelight:dirty_tin_dust',
        'createdelight:dirty_silver_dust',
        'createdelight:dirty_desh_dust',
        'createdelight:dirty_ostrum_dust',
        'createdelight:dirty_calorite_dust',
        'createdelight:tin_dust',
        'createdelight:silver_dust',
        'createdelight:desh_dust',
        'createdelight:ostrum_dust',
        'createdelight:calorite_dust',
        'createdelight:incomplete_layered_magnet',
        'createdelight:incomplete_alternator',
        'createdelight:incomplete_diesel_engine',
        'createdelight:incomplete_electric_motor',
        'createdelight:incomplete_huge_diesel_engine',
        'createdelight:incomplete_large_diesel_engine',
        'createdelight:incompleted_modular_accumulator',
        'createdelight:incomplete_electron_tube',
        'createdelight:incomplete_fs_upgrade',
        'createdelight:incomplete_graviton_tube',
        'createdelight:incomplete_cell_component_1k',
        'createdelight:incomplete_cell_component_4k',
        'createdelight:incomplete_cell_component_16k',
        'createdelight:incomplete_cell_component_64k',
        'createdelight:incomplete_cell_component_256k',
        'createdelight:incomplete_basic_card',
        'createdelight:incomplete_advanced_card',
        'createdelight:incomplete_formation_core',
        'createdelight:incomplete_annihilation_core',
        'createdelight:incomplete_me_p2p_tunnel',
        'createdelight:incomplete_charged_staff',
        'createdelight:incomplete_entropy_manipulator',
        'createdelight:incomplete_blank_pattern',
        'createdelight:incomplete_wireless_terminal',
        'createdelight:incomplete_wireless_crafting_terminal',
        'createdelight:incomplete_quantum_bridge_card',
        'createdelight:incomplete_wireless_pattern_access_terminal',
        'createdelight:incomplete_wireless_pattern_encoding_terminal',
        'createdelight:incomplete_cell_component_1m',
        'createdelight:incomplete_cell_component_4m',
        'createdelight:incomplete_cell_component_16m',
        'createdelight:incomplete_cell_component_64m',
        'createdelight:incomplete_cell_component_256m',
        'createdelight:incomplete_wireless_ex_pat',
        'createdelight:incomplete_pattern_modifier',
        'createdelight:incomplete_infinity_cell',
        'createdelight:incomplete_mega_energy_cell',
        'createdelight:incomplete_mega_crafting_unit',
        'createdelight:incomplete_decompression_module',
        'createdelight:incomplete_drive',
        'createdelight:incomplete_interface',
        'createdelight:incomplete_energy_cell',
        'createdelight:incomplete_dense_energy_cell',
        'createdelight:incomplete_crafting_unit',
        'createdelight:incomplete_pattern_provider',
        'createdelight:incomplete_molecular_assembler',
        'createdelight:incomplete_controller',
        'createdelight:incomplete_crystal_fixer',
        'createdelight:prospector',
        'createdelight:prospector_core',
        'createdelight:overworld_metal_ore_cluster',
        'createdelight:overworld_noble_metal_ore_cluster',
        'createdelight:nether_ore_cluster',
        'createdelight:moon_ore_cluster',
        'createdelight:mars_ore_cluster',
        'createdelight:mars_gemstone_cluster',
        'createdelight:mercury_ore_cluster',
        'createdelight:venus_ore_cluster',
        'createdelight:glacio_ore_cluster',
        "createdelight:planet_gear",
        "createdelight:incomplete_planet_gear",
        'createdelight:incomplete_basic_motor',
        'createdelight:incomplete_advanced_motor',
        'createdelight:incomplete_reinforced_motor',
        'createdelight:incomplete_carbon_brushes',
        "createdelight:adzuki_beans_seed",
        "createdelight:artemisia_argyi_seed",
        'createdelight:enriched_sky_stone_block',
        'createdelight:mmd_diamond',
        'createdelight:phase_transition_iron',
        'createdelight:iron_casing',
        'createdelight:space_casing',
        'createdelight:sky_steel_casing',
        'createdelight:cow_zip',
        'createdelight:sheep_zip',
        'createdelight:chicken_zip',
        'createdelight:pig_zip',
        'createdelight:goat_zip',
        'createdelight:white_rabbit_zip',
        'createdelight:black_rabbit_zip',
        'createdelight:brown_rabbit_zip',
        'createdelight:splotched_rabbit_zip',
        'createdelight:gold_rabbit_zip',
        'createdelight:electrolyzer',
        'createdelight:universal_press',
        'createdelight:dread_heart',
        'createdelight:devil_eye',
        'createdelight:demonic_codex',
        'createdelight:otherworld_note',
        'createdelight:sky_copper_ingot',
        'createdelight:incomplete_12g',
        'createdelight:incomplete_slap',
        'createdelight:incomplete_rbapb',
        'createdelight:incomplete_gas_pistol_ammo',
        'createdelight:incomplete_paper',
        'createdelight:waste_paper',
        'createdelight:unfinished_leather',
        'createdelight:inferior_genetic_seed',
        'createdelight:normal_genetic_seed',
        'createdelight:refined_genetic_seed',
        'createdelight:pure_genetic_seed',
        'createdelight:flawless_genetic_seed',
        'createdelight:bleak_electron_tube',
        'createdelight:air_helmet',
        'createdelight:air_chestplate',
        'createdelight:air_leggings',
        'createdelight:air_boots',
        'createdelight:magnetic_mechanism',
        'createdelight:incomplete_magnetic_mechanism',
        "createdelight:uranium_dust",
        "createdelight:enriched_uraniumdust",
        "createdelight:depleted_uranium_dust",
        'createdelight:yeast_bucket',
        'createdelight:dry_yeast',
        'createdelight:lime_cookie_dough',
        'createdelight:fuel_hotcream',
        'createdelight:redstone_paste',
        'createdelight:glowstone_paste',
        'createdelight:initial_processing_of_printed_engineering_processor',
        'createdelight:initial_processing_of_printed_calculation_processor',
        'createdelight:initial_processing_of_printed_logic_processor',
        'createdelight:engineering_processor_inscribed',
        'createdelight:calculation_processor_inscribed',
        'createdelight:logic_processor_inscribed',
        'createdelight:item_cell_housing_blank',
        'createdelight:fluid_cell_housing_blank',
        'createdelight:mega_fluid_cell_housing_blank',
        'createdelight:initial_processing_of_item_cell_housing',
        'createdelight:initial_processing_of_fluid_cell_housing',
        'createdelight:initial_processing_of_mega_fluid_cell_housing',
        'createdelight:unformed_item_cell_housing',
        'createdelight:unformed_item_cell_housing',
        'createdelight:unformed_mega_fluid_cell_housing',
        'createdelight:quartz_glass_parts',
        'createdelight:quartz_vibrant_glass_parts',
        'createdelight:cell_housing_curving_head',
        'createdelight:blood_collection_device',
        'createdelight:needle',
        'createdelight:dread_upgrade_smithing_template',
        'createdelight:sky_stone_paste',
        'createdelight:initial_processing_of_printed_accumulation_processor',
        'createdelight:accumulation_processor_inscribed',
        'createdelight:mega_item_cell_housing_blank',
        'createdelight:initial_processing_of_mega_item_cell_housing',
        'createdelight:unformed_mega_item_cell_housing',
        'createdelight:unformed_fluid_cell_housing',
        'createdelight:light_crude_oil_bucket',
        'createdelight:ethylene_fluid_bucket',
        'createdelight:lubricating_oil_bucket',
        'createdelight:carbon_dust',
        'createdelight:carbon_plate',
        'createdelight:aviation_fibers_sheet',
        'createdelight:basic_cabin',
        'createdelight:basic_panel',
        'createdelight:basic_crystal_panel',
        'createdelight:advanced_cabin',
        'createdelight:advanced_panel',
        'createdelight:advanced_crystal_panel',
        'createdelight:explorer_cabin',
        'createdelight:explorer_panel',
        'createdelight:holographic_interface_panel',
        'createdelight:flare_cabin',
        'createdelight:flare_panel',
        'createdelight:quantum_field_panel',
        'createdelight:incomplete_basic_panel',
        'createdelight:incomplete_advanced_panel',
        'createdelight:incomplete_explorer_panel',
        'createdelight:incomplete_flare_panel',
        'createdelight:incomplete_neapolitan_ice_cream',
        'createdelight:wrapped_fries_ghasta',
        'createdelight:enchanted_golden_lantern_fruit',
        'createdelight:enchanted_golden_carrot',
        'createdelight:enchanted_golden_arbutus_berries',
        'createdelight:raw_ghast_calamari',
        'createdelight:unbaked_red_velvet_cupcake',
        'createdelight:unbaked_mixed_berry_muffin',
        'createdelight:unbaked_chocolate_pumpkin_muffin',
        'createdelight:unbaked_blueberry_muffin',
        'createdelight:unbaked_cranberry_muffin',
        'createdelight:unbaked_monster_muffin',
        'createdelight:empty_popsicle_mold_filled',
        'createdelight:empty_popsicle_mold_solid',
        'createdelight:chorus_fruit_popsicle_mold_filled',
        'createdelight:chorus_fruit_popsicle_mold_solid',
        'createdelight:tear_popsicle_mold_filled',
        'createdelight:tear_popsicle_mold_solid',
        'createdelight:milk_popsicle_mold_filled',
        'createdelight:milk_popsicle_mold_solid',
        'createdelight:hamimelon_popsicle_mold_filled',
        'createdelight:hamimelon_popsicle_mold_solid',
        'createdelight:lime_popsicle_mold_filled',
        'createdelight:lime_popsicle_mold_solid',
        'createdelight:kiwi_popsicle_mold_filled',
        'createdelight:kiwi_popsicle_mold_solid',
        'createdelight:berry_popsicle_mold_filled',
        'createdelight:berry_popsicle_mold_solid',
        'createdelight:big_popsicle_mold_filled',
        'createdelight:big_popsicle_mold_solid',
        'createdelight:green_tongue_mold_filled',
        'createdelight:green_tongue_mold_solid',
        'createdelight:lush_confiture_jello_item',
        'createdelight:wafer_dough',
        'createdelight:raw_potato_pancake'
    ])
});

==> 2025-12-26-14-33-27-Create-Delight-Remake-Client.Create-Delight-Remake-v0.4.7.8.zip: overrides/kubejs/startup_scripts/creative_tab/kubejs.js <==
StartupEvents.modifyCreativeTab("kubejs:tab", e => {
    e.remove([
        'createdelight:fire_dragonsteel_armorplate',
        'createdelight:ice_dragonsteel_armorplate',
        'createdelight:lightning_dragonsteel_armorplate',
        'createdelight:incomplete_fire_dragonsteel_armorplate',
        'createdelight:incomplete_ice_dragonsteel_armorplate',
        'createdelight:incomplete_lightning_dragonsteel_armorplate',
        'createdelight:fire_dragon_blood_bucket',
        'createdelight:ice_dragon_blood_bucket',
        'createdelight:lightning_dragon_blood_bucket',
        'createdelight:fuel_mixtures_bucket',
        'createdelight:sky_solution_bucket',
        'createdelight:spent_liquor_bucket',
        'createdelight:unrefined_sugar_bucket',
        'createdelight:unfermented_paper_pulp_bucket',
        'createdelight:paper_pulp_bucket',
        'createdelight:radon_bucket',
        'createdelight:cake_batter_bucket',
        'createdelight:egg_yolk_bucket',
        'createdelight:nut_milk_bucket',
        'createdelight:vinegar_bucket',
        'createdelight:malice_solution_bucket',
        'createdelight:artificial_egg_yolk_bucket',
        'createdelight:soya_milk_bucket',
        'createdelight:corn_flour',
        'createdelight:butter',
        'createdelight:oil_dough',
        'createdelight:oil_dough_with_butter',
        'createdelight:puff_pastry',
        'createdelight:board_noodles',
        'createdelight:vermicelli',
        'createdelight:persimmon_cookie_dough',
        'createdelight:lemon_cookie_dough',
        'createdelight:oatmeal_cookie_dough',
        'createdelight:green_tea_cookie_dough',
        'createdelight:cranberry_cookie_dough',
        'createdelight:bayberry_cookie_dough',
        'createdelight:chocolate_cookie_dough',
        'createdelight:honey_cookie_dough',
        'createdelight:sweet_berry_cookie_dough',
        'createdelight:chorus_cookie_dough',
        'createdelight:bat_cookie_dough',
        'createdelight:paw_cookie_dough',
        'createdelight:raw_empanada',
        'createdelight:raw_calamari',
        'createdelight:raw_cheese_pizza',
        'createdelight:oat_bread',
        'createdelight:ketchup_corn_dog',
        'createdelight:mayo_corn_dog',
        'createdelight:salami',
        'createdelight:potato_stew_beef',
        'createdelight:sushi_unrolledroll',
        'createdelight:fugu_roll',
        'createdelight:empty_riceball',
        'createdelight:yorkshire_pudding_and_beef',
        'createdelight:boiling_water_cabbage',
        'createdelight:braised_intestines_in_brown_sauce',
        'createdelight:empty_popsicle',
        'createdelight:potato_stew_beef',
        'createdelight:sushi_unrolledroll',
        'createdelight:forged_steel_sheet',
        'createdelight:andesite_alloy_nugget',
        'createdelight:crushed_raw_desh',
        'createdelight:crushed_raw_ostrum',
        'createdelight:crushed_raw_calorite',
        'createdelight:dirty_tin_dust',
        'createdelight:dirty_silver_dust',
        'createdelight:dirty_desh_dust',
        'createdelight:dirty_ostrum_dust',
        'createdelight:dirty_calorite_dust',
        'createdelight:tin_dust',
        'createdelight:silver_dust',
        'createdelight:desh_dust',
        'createdelight:ostrum_dust',
        'createdelight:calorite_dust',
        'createdelight:incomplete_layered_magnet',
        'createdelight:incomplete_alternator',
        'createdelight:incomplete_diesel_engine',
        'createdelight:incomplete_electric_motor',
        'createdelight:incomplete_huge_diesel_engine',
        'createdelight:incomplete_large_diesel_engine',
        'createdelight:incompleted_modular_accumulator',
        'createdelight:incomplete_electron_tube',
        'createdelight:incomplete_fs_upgrade',
        'createdelight:incomplete_graviton_tube',
        'createdelight:incomplete_cell_component_1k',
        'createdelight:incomplete_cell_component_4k',
        'createdelight:incomplete_cell_component_16k',
        'createdelight:incomplete_cell_component_64k',
        'createdelight:incomplete_cell_component_256k',
        'createdelight:incomplete_basic_card',
        'createdelight:incomplete_advanced_card',
        'createdelight:incomplete_formation_core',
        'createdelight:incomplete_annihilation_core',
        'createdelight:incomplete_me_p2p_tunnel',
        'createdelight:incomplete_charged_staff',
        'createdelight:incomplete_entropy_manipulator',
        'createdelight:incomplete_blank_pattern',
        'createdelight:incomplete_wireless_terminal',
        'createdelight:incomplete_wireless_crafting_terminal',
        'createdelight:incomplete_quantum_bridge_card',
        'createdelight:incomplete_wireless_pattern_access_terminal',
        'createdelight:incomplete_wireless_pattern_encoding_terminal',
        'createdelight:incomplete_cell_component_1m',
        'createdelight:incomplete_cell_component_4m',
        'createdelight:incomplete_cell_component_16m',
        'createdelight:incomplete_cell_component_64m',
        'createdelight:incomplete_cell_component_256m',
        'createdelight:incomplete_wireless_ex_pat',
        'createdelight:incomplete_pattern_modifier',
        'createdelight:incomplete_infinity_cell',
        'createdelight:incomplete_mega_energy_cell',
        'createdelight:incomplete_mega_crafting_unit',
        'createdelight:incomplete_decompression_module',
        'createdelight:incomplete_drive',
        'createdelight:incomplete_interface',
        'createdelight:incomplete_energy_cell',
        'createdelight:incomplete_dense_energy_cell',
        'createdelight:incomplete_crafting_unit',
        'createdelight:incomplete_pattern_provider',
        'createdelight:incomplete_molecular_assembler',
        'createdelight:incomplete_controller',
        'createdelight:incomplete_crystal_fixer',
        'createdelight:prospector',
        'createdelight:prospector_core',
        'createdelight:overworld_metal_ore_cluster',
        'createdelight:overworld_noble_metal_ore_cluster',
        'createdelight:nether_ore_cluster',
        'createdelight:moon_ore_cluster',
        'createdelight:mars_ore_cluster',
        'createdelight:mars_gemstone_cluster',
        'createdelight:mercury_ore_cluster',
        'createdelight:venus_ore_cluster',
        'createdelight:glacio_ore_cluster',
        "createdelight:planet_gear",
        "createdelight:incomplete_planet_gear",
        'createdelight:incomplete_basic_motor',
        'createdelight:incomplete_advanced_motor',
        'createdelight:incomplete_reinforced_motor',
        'createdelight:incomplete_carbon_brushes',
        "createdelight:adzuki_beans_seed",
        "createdelight:artemisia_argyi_seed",
        'createdelight:enriched_sky_stone_block',
        'createdelight:mmd_diamond',
        'createdelight:phase_transition_iron',
        'createdelight:iron_casing',
        'createdelight:space_casing',
        'createdelight:sky_steel_casing',
        'createdelight:cow_zip',
        'createdelight:sheep_zip',
        'createdelight:chicken_zip',
        'createdelight:pig_zip',
        'createdelight:goat_zip',
        'createdelight:white_rabbit_zip',
        'createdelight:black_rabbit_zip',
        'createdelight:brown_rabbit_zip',
        'createdelight:splotched_rabbit_zip',
        'createdelight:gold_rabbit_zip',
        'createdelight:electrolyzer',
        'createdelight:universal_press',
        'createdelight:dread_heart',
        'createdelight:devil_eye',
        'createdelight:demonic_codex',
        'createdelight:otherworld_note',
        'createdelight:sky_copper_ingot',
        'createdelight:incomplete_12g',
        'createdelight:incomplete_slap',
        'createdelight:incomplete_rbapb',
        'createdelight:incomplete_gas_pistol_ammo',
        'createdelight:incomplete_paper',
        'createdelight:waste_paper',
        'createdelight:unfinished_leather',
        'createdelight:inferior_genetic_seed',
        'createdelight:normal_genetic_seed',
        'createdelight:refined_genetic_seed',
        'createdelight:pure_genetic_seed',
        'createdelight:flawless_genetic_seed',
        'createdelight:bleak_electron_tube',
        'createdelight:air_helmet',
        'createdelight:air_chestplate',
        'createdelight:air_leggings',
        'createdelight:air_boots',
        'createdelight:magnetic_mechanism',
        'createdelight:incomplete_magnetic_mechanism',
        "createdelight:uranium_dust",
        "createdelight:enriched_uraniumdust",
        "createdelight:depleted_uranium_dust",
        'createdelight:yeast_bucket',
        'createdelight:dry_yeast',
        'createdelight:lime_cookie_dough',
        'createdelight:fuel_hotcream',
        'createdelight:redstone_paste',
        'createdelight:glowstone_paste',
        'createdelight:initial_processing_of_printed_engineering_processor',
        'createdelight:initial_processing_of_printed_calculation_processor',
        'createdelight:initial_processing_of_printed_logic_processor',
        'createdelight:engineering_processor_inscribed',
        'createdelight:calculation_processor_inscribed',
        'createdelight:logic_processor_inscribed',
        'createdelight:item_cell_housing_blank',
        'createdelight:fluid_cell_housing_blank',
        'createdelight:mega_fluid_cell_housing_blank',
        'createdelight:initial_processing_of_item_cell_housing',
        'createdelight:initial_processing_of_fluid_cell_housing',
        'createdelight:initial_processing_of_mega_fluid_cell_housing',
        'createdelight:unformed_item_cell_housing',
        'createdelight:unformed_item_cell_housing',
        'createdelight:unformed_mega_fluid_cell_housing',
        'createdelight:quartz_glass_parts',
        'createdelight:quartz_vibrant_glass_parts',
        'createdelight:cell_housing_curving_head',
        'createdelight:blood_collection_device',
        'createdelight:needle',
        'createdelight:dread_upgrade_smithing_template',
        'createdelight:sky_stone_paste',
        'createdelight:initial_processing_of_printed_accumulation_processor',
        'createdelight:accumulation_processor_inscribed',
        'createdelight:mega_item_cell_housing_blank',
        'createdelight:initial_processing_of_mega_item_cell_housing',
        'createdelight:unformed_mega_item_cell_housing',
        'createdelight:unformed_fluid_cell_housing',
        'createdelight:light_crude_oil_bucket',
        'createdelight:ethylene_fluid_bucket',
        'createdelight:lubricating_oil_bucket',
        'createdelight:carbon_dust',
        'createdelight:carbon_plate',
        'createdelight:aviation_fibers_sheet',
        'createdelight:basic_cabin',
        'createdelight:basic_panel',
        'createdelight:basic_crystal_panel',
        'createdelight:advanced_cabin',
        'createdelight:advanced_panel',
        'createdelight:advanced_crystal_panel',
        'createdelight:explorer_cabin',
        'createdelight:explorer_panel',
        'createdelight:holographic_interface_panel',
        'createdelight:flare_cabin',
        'createdelight:flare_panel',
        'createdelight:quantum_field_panel',
        'createdelight:incomplete_basic_panel',
        'createdelight:incomplete_advanced_panel',
        'createdelight:incomplete_explorer_panel',
        'createdelight:incomplete_flare_panel',
        'createdelight:incomplete_neapolitan_ice_cream',
        'createdelight:wrapped_fries_ghasta',
        'createdelight:enchanted_golden_lantern_fruit',
        'createdelight:enchanted_golden_carrot',
        'createdelight:enchanted_golden_arbutus_berries',
        'createdelight:raw_ghast_calamari',
        'createdelight:unbaked_red_velvet_cupcake',
        'createdelight:unbaked_mixed_berry_muffin',
        'createdelight:unbaked_chocolate_pumpkin_muffin',
        'createdelight:unbaked_blueberry_muffin',
        'createdelight:unbaked_cranberry_muffin',
        'createdelight:unbaked_monster_muffin',
        'createdelight:empty_popsicle_mold_filled',
        'createdelight:empty_popsicle_mold_solid',
        'createdelight:chorus_fruit_popsicle_mold_filled',
        'createdelight:chorus_fruit_popsicle_mold_solid',
        'createdelight:tear_popsicle_mold_filled',
        'createdelight:tear_popsicle_mold_solid',
        'createdelight:milk_popsicle_mold_filled',
        'createdelight:milk_popsicle_mold_solid',
        'createdelight:hamimelon_popsicle_mold_filled',
        'createdelight:hamimelon_popsicle_mold_solid',
        'createdelight:lime_popsicle_mold_filled',
        'createdelight:lime_popsicle_mold_solid',
        'createdelight:kiwi_popsicle_mold_filled',
        'createdelight:kiwi_popsicle_mold_solid',
        'createdelight:berry_popsicle_mold_filled',
        'createdelight:berry_popsicle_mold_solid',
        'createdelight:big_popsicle_mold_filled',
        'createdelight:big_popsicle_mold_solid',
        'createdelight:green_tongue_mold_filled',
        'createdelight:green_tongue_mold_solid',
        'createdelight:lush_confiture_jello_item',
        'createdelight:wafer_dough',
        'createdelight:raw_potato_pancake',
        'createdelight:order_deliverer_item',
        "createdelight:guncotton",
        "createdelight:incomplete_gunkan",
        "createdelight:incomplete_nigiri",
        "createdelight:incomplete_hosomaki",
        "createdelight:incomplete_futomaki",
        "createdelight:incomplete_california",
        "createdelight:radgill_sushi",
        'createdelight:deep_sea_sushi_roll_slice',
    ])
});
